==> checker-3.4.0.jar: annotated-jdk/src/java.base/share/classes/java/security/spec/MGF1ParameterSpec.java <==
/*
 * Copyright (c) 2003, 2018, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the LICENSE file that accompanied this code.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */
package java.security.spec;

import org.checkerframework.checker.interning.qual.UsesObjectEquals;
import org.checkerframework.framework.qual.AnnotatedFor;
import java.security.spec.AlgorithmParameterSpec;

@AnnotatedFor({ "interning" })
@UsesObjectEquals
public class MGF1ParameterSpec implements AlgorithmParameterSpec {

    public static final MGF1ParameterSpec SHA1;

    public static final MGF1ParameterSpec SHA224;

    public static final MGF1ParameterSpec SHA256;

    public static final MGF1ParameterSpec SHA384;

    public static final MGF1ParameterSpec SHA512;

    public static final MGF1ParameterSpec SHA512_224;

    public static final MGF1ParameterSpec SHA512_256;

    public MGF1ParameterSpec(String mdName) {
    }

    public String getDigestAlgorithm();
}

==> checker-3.32.0.jar: annotated-jdk/src/java.base/share/classes/java/security/spec/MGF1ParameterSpec.java <==
/*
 * Copyright (c) 2003, 2020, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the LICENSE file that accompanied this code.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */
package java.security.spec;

import org.checkerframework.checker.interning.qual.UsesObjectEquals;
import org.checkerframework.framework.qual.AnnotatedFor;

@AnnotatedFor({ "interning" })
@UsesObjectEquals
public class MGF1ParameterSpec implements AlgorithmParameterSpec {

    public static final MGF1ParameterSpec SHA1;

    public static final MGF1ParameterSpec SHA224;

    public static final MGF1ParameterSpec SHA256;

    public static final MGF1ParameterSpec SHA384;

    public static final MGF1ParameterSpec SHA512;

    public static final MGF1ParameterSpec SHA512_224;

    public static final MGF1ParameterSpec SHA512_256;

    public static final MGF1ParameterSpec SHA3_224;

    public static final MGF1ParameterSpec SHA3_256;

    public static final MGF1ParameterSpec SHA3_384;

    public static final MGF1ParameterSpec SHA3_512;

    public MGF1ParameterSpec(String mdName) {
    }

    public String getDigestAlgorithm();

    @Override
    public String toString();
}
